##############################################
### all code for analyses in Rainey et al. ###
##############################################

# note: this code shows how to conduct analyses
# from aligned Procrustes coordinates—--not
# from raw coordinates from photographs.

rm(list=ls())

# load packages
library(geomorph)

# read data
latData <- read.csv("Supplemental_File_1_Lateral_Aligned_Coordinates.csv", 
                    header = T, stringsAsFactors = T)
ventData <- read.csv("Supplemental_File_2_Ventral_Aligned_Coordinates.csv", 
                     header = T, stringsAsFactors = T)
metadata <- read.csv("Supplemental_File_3_Specimen_Metadata.csv", 
                     header = T, stringsAsFactors = T)

# make sure data match
identical(latData$specimen, ventData$specimen)
identical(latData$specimen, metadata$specimen)

# organize data for analyses
morphsex <- metadata$morphsex
latCoords <- as.matrix(latData[, 2:25])
ventCoords <- as.matrix(ventData[, 2:27])

# create dataframe for analyses
latGDF <- geomorph.data.frame(latCoords, morphsex = morphsex)
ventGDF <- geomorph.data.frame(ventCoords, morphsex = morphsex)

# conduct non-parametric MANOVA for lateral view
latMod <- procD.lm(latCoords ~ morphsex, data = latGDF, 
                iter = 9999, RRPP = TRUE, seed = 1234)
summary(latMod)
# look at pairwise comparison
latPW <- pairwise(latMod, groups = morphsex)
summary(latPW, test.type = "dist", confidence = 0.95, stat.table = FALSE)

# conduct non-parametric MANOVA for lateral view
ventMod <- procD.lm(ventCoords ~ morphsex, data = ventGDF, 
                   iter = 9999, RRPP = TRUE, seed = 1234)
summary(ventMod)
# look at pairwise comparison
ventPW <- pairwise(ventMod, groups = morphsex)
summary(ventPW, test.type = "dist", confidence = 0.95, stat.table = FALSE)
        
# set warp grid parameters
warp.par <- gridPar(pt.bg = "black", pt.size = 1.5, link.col = "black", link.lwd = 2,link.lty = 1, out.col = "gray", out.cex = 0.1, tar.pt.bg = "black",
                    tar.pt.size = 1, tar.link.col = "black", tar.link.lwd = 2,
                    tar.link.lty = 1, tar.out.col = "black", tar.out.cex = 0.1,
                    n.col.cell = 20, grid.col = "gray", grid.lwd = 4, grid.lty = 1,
                    txt.adj = 0.5, txt.pos = 1, txt.cex = 0.8, txt.col = "black")

# convert matrices to three-dimensional arrays
latArray <- arrayspecs(latCoords, 12, 2)  
latMeanShape <- mshape(latArray)
latLinks <- cbind(c(1,2,5,3,6,7,8,9,10,11,12),c(2,5,3,6,7,8,9,10,11,12,1))

ventArray <- arrayspecs(ventCoords, 13, 2)  
ventMeanShape <- mshape(ventArray)
ventLinks <- cbind(c(1,2,3,4,5,6,7,8,9,10,11,12),c(2,3,4,5,6,7,8,9,10,11,12,13))

# create and plot warp grids for lateral view
latFemaleMean <- mshape(latArray[, , morphsex == "female"])
plotRefToTarget(latMeanShape, latFemaleMean, mag = 3, 
                links = latLinks, gridPars = warp.par)

latGuardingMean <- mshape(latArray[, , morphsex == "guarding"])
plotRefToTarget(latMeanShape, latGuardingMean, mag = 3, 
                links = latLinks, gridPars = warp.par)

latSearchingMean <- mshape(latArray[, , morphsex == "searching"])
plotRefToTarget(latMeanShape, latSearchingMean, mag = 3, 
                links = latLinks, gridPars = warp.par)

# create and plot warp grids for ventral view
ventFemaleMean <- mshape(ventArray[, , morphsex == "female"])
plotRefToTarget(ventMeanShape, ventFemaleMean, mag = 3, 
                links = ventLinks, gridPars = warp.par)

ventGuardingMean <- mshape(ventArray[, , morphsex == "guarding"])
plotRefToTarget(ventMeanShape, ventGuardingMean, mag = 3, 
                links = ventLinks, gridPars = warp.par)

ventSearchingMean <- mshape(ventArray[, , morphsex == "searching"])
plotRefToTarget(ventMeanShape, ventSearchingMean, mag = 3, 
                links = ventLinks, gridPars = warp.par)

# conduct and plot PCAs
# conduct PCAs, summarize, and extract coordinates
latPCA <- gm.prcomp(latCoords)
summary(latPCA)
latPCAscores <- latPCA$x

ventPCA <- gm.prcomp(ventCoords)
summary(ventPCA)
ventPCAscores <- ventPCA$x

# create color vectors
cols <- vector(length = length(morphsex))
cols[morphsex == "female"] <- "black"
cols[morphsex == "guarding"] <- "gray"
cols[morphsex == "searching"] <- "white"

# plot first two axes with means
plot(latPCAscores[,1], latPCAscores[,2], bg = cols,
     pch = 21, xlab = "PC1 (23.3%)",
     ylab = "PC2 (19.7%)", xaxt = 'n', yaxt = 'n')
points(mean(latPCAscores[morphsex == "female", 1]), 
       mean(latPCAscores[morphsex == "female", 2]),
       cex = 2, pch = 21, bg = "black")
points(mean(latPCAscores[morphsex == "guarding", 1]), 
       mean(latPCAscores[morphsex == "guarding", 2]),
       cex = 2, pch = 21, bg = "gray")
points(mean(latPCAscores[morphsex == "searching", 1]), 
       mean(latPCAscores[morphsex == "searching", 2]),
       cex = 2, pch = 21, bg = "white")

plot(ventPCAscores[,1], ventPCAscores[,2], bg = cols,
     pch = 21, xlab = "PC1 (52.0%)",
     ylab = "PC2 (16.4%)", xaxt = 'n', yaxt = 'n',
     )
points(mean(ventPCAscores[morphsex == "female", 1]), 
       mean(ventPCAscores[morphsex == "female", 2]),
       cex = 2, pch = 21, bg = "black")
points(mean(ventPCAscores[morphsex == "guarding", 1]), 
       mean(ventPCAscores[morphsex == "guarding", 2]),
       cex = 2, pch = 21, bg = "gray")
points(mean(ventPCAscores[morphsex == "searching", 1]), 
       mean(ventPCAscores[morphsex == "searching", 2]),
       cex = 2, pch = 21, bg = "white")